==> amarok-2.7.0.tar.bz2: amarok-2.7.0/src/core-impl/playlists/providers/user/UserPlaylistProvider.h <==
/****************************************************************************************
 * Copyright (c) 2008 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 * Copyright (c) 2008 Bart Cerneels <bart.cerneels@kde.org>                             *
 * Copyright (c) 2012 Ralf Engels <ralf-engels@gmx.de>                                  *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef USERPLAYLISTPROVIDER_H
#define USERPLAYLISTPROVIDER_H

#include "core/playlists/Playlist.h"
#include "core/playlists/PlaylistProvider.h"

class QAction;

namespace Playlists {

/**
    @author Bart Cerneels <bart.cerneels@kde.org>
*/
class AMAROK_EXPORT UserPlaylistProvider : public PlaylistProvider
{
    Q_OBJECT
    public:
        explicit UserPlaylistProvider( QObject *parent = 0 );
        virtual ~UserPlaylistProvider();

        /* PlaylistProvider functions */
        virtual int category() const;

        /* UserPlaylistProvider functions */
        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks,
                                             const QString& name = QString() ) = 0;

        virtual QList<QAction *> playlistActions( Playlists::PlaylistPtr playlist );
        virtual QList<QAction *> trackActions( Playlists::PlaylistPtr playlist,
                                                  int trackIndex );

        // UserPlaylistProvider-specific
        virtual bool isWritable() { return false; }
        virtual void rename( Playlists::PlaylistPtr playlist, const QString &newName )
                { Q_UNUSED( playlist ) Q_UNUSED(newName) }
        virtual bool deletePlaylists( Playlists::PlaylistList playlistlist )
                { Q_UNUSED( playlistlist ) return false; }

    protected slots:
        /**
         * Delete selected playlists.
         * Will only work if the sender is a QAction with a PlaylistPtr as data.
         */
        virtual void slotDelete();

        /**
         * Rename selected playlist.
         * Will only work if the sender is a QAction with a PlaylistPtr as data.
         */
        virtual void slotRename();

        /**
         * Export the selected playlist.
         * Will only work if the sender is a QAction with a PlaylistPtr as data.
         */
        virtual void slotExport();

        /**
         * Remove a track (or tracks) from a playlist.
         * Will only work if the sender is a QAction with a PlaylistTrackMap as data.
         */
        virtual void slotRemoveTrack();

    protected:
        QAction *m_deleteAction;
        QAction *m_renameAction;
        QAction *m_exportAction;
        QAction *m_removeTrackAction;
};

} //namespace Playlists

#endif

==> amarok-2.8.0.tar.bz2: amarok-2.8.0/src/core-impl/playlists/providers/user/UserPlaylistProvider.h <==
/****************************************************************************************
 * Copyright (c) 2008 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 * Copyright (c) 2008 Bart Cerneels <bart.cerneels@kde.org>                             *
 * Copyright (c) 2012 Ralf Engels <ralf-engels@gmx.de>                                  *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef USERPLAYLISTPROVIDER_H
#define USERPLAYLISTPROVIDER_H

#include "amarok_export.h"
#include "core/playlists/PlaylistProvider.h"

namespace Playlists {
    /**
     * @author Bart Cerneels <bart.cerneels@kde.org>
     */
    class AMAROK_EXPORT UserPlaylistProvider : public PlaylistProvider
    {
        Q_OBJECT

        public:
            explicit UserPlaylistProvider( QObject *parent = 0 );

            /* PlaylistProvider functions */
            virtual int category() const;

            /* UserPlaylistProvider functions */
            virtual PlaylistPtr save( const Meta::TrackList &tracks,
                                      const QString &name = QString() ) = 0;
    };
} //namespace Playlists

#endif
